@@ -47,6 +47,10 @@
 #include <cerrno>
 #include <csignal>
 
+#ifdef  HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #ifdef  MACOSX
 #undef  _POSIX_PRIORITY_SCHEDULING
 #endif
@@ -461,7 +465,6 @@ void    Process::detach(void)
 void    Process::attach(const char *dev)
 {
     int pid;
-    int fd;
 
     if(getppid() == 1)
         return;
@@ -489,6 +492,7 @@ void    Process::attach(const char *dev)
 
 
 #if defined(SIGTSTP) && defined(TIOCNOTTY)
+    int fd;
     if(setpgid(0, getpid()) == -1)
         THROW(-1);
 
@@ -525,10 +529,13 @@ void Process::setScheduler(const char *pol)
 {
 #ifdef  _POSIX_PRIORITY_SCHEDULING
     struct sched_param p;
-    int policy;
+    int policy, orig;
+    pthread_t ptid = pthread_self();
 
-    sched_getparam(0, &p);
+    if(pthread_getschedparam(ptid, &policy, &p))
+        return;
 
+    orig = policy;
     if(pol) {
 #if defined(SCHED_TS)
         policy = SCHED_TS;
@@ -562,7 +569,7 @@ void Process::setScheduler(const char *pol)
 #endif
     }
     else
-        policy = sched_getscheduler(0);
+        policy = orig;
 
     int min = sched_get_priority_min(policy);
     int max = sched_get_priority_max(policy);
@@ -572,7 +579,7 @@ void Process::setScheduler(const char *pol)
     else if(p.sched_priority > max)
         p.sched_priority = max;
 
-    sched_setscheduler(0, policy, &p);
+    pthread_setschedparam(ptid, policy, &p);
 #endif
 }
 
@@ -580,18 +587,20 @@ void Process::setPriority(int pri)
 {
 #ifdef  _POSIX_PRIORITY_SCHEDULING
     struct sched_param p;
-    int policy = sched_getscheduler(0);
+    int policy;
+    pthread_t ptid = pthread_self();
+
+    pthread_getschedparam(ptid, &policy, &p);
+
     int min = sched_get_priority_min(policy);
     int max = sched_get_priority_max(policy);
 
-    sched_getparam(0, &p);
-
     if(pri < min)
         pri = min;
     if(pri > max)
         pri = max;
     p.sched_priority = pri;
-    sched_setparam(0, &p);
+    pthread_setschedparam(ptid, policy, &p);
 #else
     if(pri < -20)
         pri = -20;
