@@ -24,8 +24,8 @@
 #ifndef _UCOMMON_GENERICS_H_
 #define _UCOMMON_GENERICS_H_
 
-#ifndef _UCOMMON_CONFIG_H_
-#include <ucommon/platform.h>
+#ifndef _UCOMMON_CPR_H_
+#include <ucommon/cpr.h>
 #endif
 
 #include <stdlib.h>
@@ -414,6 +414,32 @@ public:
     }
 };
 
+/**
+ * Save and restore global objects in function call stack frames.
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+template<typename T>
+class save_restore
+{
+private:
+    T *original;
+    T temp;
+
+public:
+    /**
+     * Save object into local copy and keep reference to the original object.
+     * @param object to save.
+     */
+    inline save_restore(T& object)
+        {original = &object; temp = object;};
+
+    /**
+     * Restore original when stack frame is released.
+     */
+    inline ~save_restore()
+        {*original = temp;};
+};
+
 /**
  * Convenience function to validate object assuming it is castable to bool.
  * @param object we are testing.
